==> haskell-gi-gtk-debug-4.0.9-13-x86_64.pkg.tar.zst: usr/src/debug/haskell-gi-gtk/gi-gtk-4.0.9/GI/Gtk/Objects/ParamSpecExpression.hs <==
{-# LANGUAGE TypeApplications #-}


-- | Copyright  : Will Thompson and Iñaki García Etxebarria
-- License    : LGPL-2.1
-- Maintainer : Iñaki García Etxebarria
-- 
-- A @GParamSpec@ for properties holding a @GtkExpression@.

#if (MIN_VERSION_haskell_gi_overloading(1,0,0) && !defined(__HADDOCK_VERSION__))
#define ENABLE_OVERLOADING
#endif

module GI.Gtk.Objects.ParamSpecExpression
    ( 

-- * Exported types
    ParamSpecExpression(..)                 ,
    IsParamSpecExpression                   ,
    toParamSpecExpression                   ,


 -- * Methods
-- | 
-- 
--  === __Click to display all available methods, including inherited ones__
-- ==== Methods
-- [sink]("GI.GObject.Objects.ParamSpec#g:method:sink"), [stealQdata]("GI.GObject.Objects.ParamSpec#g:method:stealQdata").
-- 
-- ==== Getters
-- [getBlurb]("GI.GObject.Objects.ParamSpec#g:method:getBlurb"), [getDefaultValue]("GI.GObject.Objects.ParamSpec#g:method:getDefaultValue"), [getName]("GI.GObject.Objects.ParamSpec#g:method:getName"), [getNameQuark]("GI.GObject.Objects.ParamSpec#g:method:getNameQuark"), [getNick]("GI.GObject.Objects.ParamSpec#g:method:getNick"), [getQdata]("GI.GObject.Objects.ParamSpec#g:method:getQdata"), [getRedirectTarget]("GI.GObject.Objects.ParamSpec#g:method:getRedirectTarget").
-- 
-- ==== Setters
-- [setQdata]("GI.GObject.Objects.ParamSpec#g:method:setQdata").

#if defined(ENABLE_OVERLOADING)
    ResolveParamSpecExpressionMethod        ,
#endif



    ) where

import Data.GI.Base.ShortPrelude
import qualified Data.GI.Base.ShortPrelude as SP
import qualified Data.GI.Base.Overloading as O
import qualified Prelude as P

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.GI.Base.BasicTypes as B.Types
import qualified Data.GI.Base.ManagedPtr as B.ManagedPtr
import qualified Data.GI.Base.GArray as B.GArray
import qualified Data.GI.Base.GClosure as B.GClosure
import qualified Data.GI.Base.GError as B.GError
import qualified Data.GI.Base.GHashTable as B.GHT
import qualified Data.GI.Base.GVariant as B.GVariant
import qualified Data.GI.Base.GValue as B.GValue
import qualified Data.GI.Base.GParamSpec as B.GParamSpec
import qualified Data.GI.Base.CallStack as B.CallStack
import qualified Data.GI.Base.Properties as B.Properties
import qualified Data.GI.Base.Signals as B.Signals
import qualified Control.Monad.IO.Class as MIO
import qualified Data.Coerce as Coerce
import qualified Data.Text as T
import qualified Data.Kind as DK
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map
import qualified Foreign.Ptr as FP
import qualified GHC.OverloadedLabels as OL
import qualified GHC.Records as R
import qualified Data.Word as DW
import qualified Data.Int as DI
import qualified System.Posix.Types as SPT
import qualified Foreign.C.Types as FCT

-- Workaround for https://gitlab.haskell.org/ghc/ghc/-/issues/23392
#if MIN_VERSION_base(4,18,0)
import qualified GI.GObject.Objects.ParamSpec as GObject.ParamSpec

#else
import qualified GI.GObject.Objects.ParamSpec as GObject.ParamSpec

#endif

-- | Memory-managed wrapper type.
newtype ParamSpecExpression = ParamSpecExpression (SP.ManagedPtr ParamSpecExpression)
    deriving (Eq)

instance SP.ManagedPtrNewtype ParamSpecExpression where
    toManagedPtr (ParamSpecExpression p) = p

foreign import ccall "gtk_param_expression_get_type"
    c_gtk_param_expression_get_type :: IO B.Types.GType

instance B.Types.TypedObject ParamSpecExpression where
    glibType = c_gtk_param_expression_get_type

-- | Type class for types which can be safely cast to `ParamSpecExpression`, for instance with `toParamSpecExpression`.
class (SP.BoxedPtr o, SP.TypedObject o, O.IsDescendantOf ParamSpecExpression o) => IsParamSpecExpression o
instance (SP.BoxedPtr o, SP.TypedObject o, O.IsDescendantOf ParamSpecExpression o) => IsParamSpecExpression o

instance O.HasParentTypes ParamSpecExpression
type instance O.ParentTypes ParamSpecExpression = '[GObject.ParamSpec.ParamSpec]

-- | Cast to `ParamSpecExpression`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
toParamSpecExpression :: (MIO.MonadIO m, IsParamSpecExpression o) => o -> m ParamSpecExpression
toParamSpecExpression = MIO.liftIO . B.ManagedPtr.unsafeCastTo ParamSpecExpression

--- XXX Missing getter and/or setter, so no GValue instance could be generated.
#if defined(ENABLE_OVERLOADING)
type family ResolveParamSpecExpressionMethod (t :: Symbol) (o :: DK.Type) :: DK.Type where
    ResolveParamSpecExpressionMethod "sink" o = GObject.ParamSpec.ParamSpecSinkMethodInfo
    ResolveParamSpecExpressionMethod "stealQdata" o = GObject.ParamSpec.ParamSpecStealQdataMethodInfo
    ResolveParamSpecExpressionMethod "getBlurb" o = GObject.ParamSpec.ParamSpecGetBlurbMethodInfo
    ResolveParamSpecExpressionMethod "getDefaultValue" o = GObject.ParamSpec.ParamSpecGetDefaultValueMethodInfo
    ResolveParamSpecExpressionMethod "getName" o = GObject.ParamSpec.ParamSpecGetNameMethodInfo
    ResolveParamSpecExpressionMethod "getNameQuark" o = GObject.ParamSpec.ParamSpecGetNameQuarkMethodInfo
    ResolveParamSpecExpressionMethod "getNick" o = GObject.ParamSpec.ParamSpecGetNickMethodInfo
    ResolveParamSpecExpressionMethod "getQdata" o = GObject.ParamSpec.ParamSpecGetQdataMethodInfo
    ResolveParamSpecExpressionMethod "getRedirectTarget" o = GObject.ParamSpec.ParamSpecGetRedirectTargetMethodInfo
    ResolveParamSpecExpressionMethod "setQdata" o = GObject.ParamSpec.ParamSpecSetQdataMethodInfo
    ResolveParamSpecExpressionMethod l o = O.MethodResolutionFailed l o

instance (info ~ ResolveParamSpecExpressionMethod t ParamSpecExpression, O.OverloadedMethod info ParamSpecExpression p) => OL.IsLabel t (ParamSpecExpression -> p) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.overloadedMethod @info
#else
    fromLabel _ = O.overloadedMethod @info
#endif

#if MIN_VERSION_base(4,13,0)
instance (info ~ ResolveParamSpecExpressionMethod t ParamSpecExpression, O.OverloadedMethod info ParamSpecExpression p, R.HasField t ParamSpecExpression p) => R.HasField t ParamSpecExpression p where
    getField = O.overloadedMethod @info

#endif

instance (info ~ ResolveParamSpecExpressionMethod t ParamSpecExpression, O.OverloadedMethodInfo info ParamSpecExpression) => OL.IsLabel t (O.MethodProxy info ParamSpecExpression) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.MethodProxy
#else
    fromLabel _ = O.MethodProxy
#endif

#endif

-- XXX Wrapping a foreign struct/union with no known destructor or size, leak?
instance BoxedPtr ParamSpecExpression where
    boxedPtrCopy = return
    boxedPtrFree = \_x -> return ()

==> haskell-gi-gtk-debug-4.0.11-27-x86_64.pkg.tar.zst: usr/src/debug/haskell-gi-gtk/gi-gtk-4.0.11/GI/Gtk/Objects/ParamSpecExpression.hs <==
{-# LANGUAGE TypeApplications #-}


-- | Copyright  : Will Thompson and Iñaki García Etxebarria
-- License    : LGPL-2.1
-- Maintainer : Iñaki García Etxebarria
-- 
-- A @GParamSpec@ for properties holding a @GtkExpression@.

#if (MIN_VERSION_haskell_gi_overloading(1,0,0) && !defined(__HADDOCK_VERSION__))
#define ENABLE_OVERLOADING
#endif

module GI.Gtk.Objects.ParamSpecExpression
    ( 

-- * Exported types
    ParamSpecExpression(..)                 ,
    IsParamSpecExpression                   ,
    toParamSpecExpression                   ,


 -- * Methods
-- | 
-- 
--  === __Click to display all available methods, including inherited ones__
-- ==== Methods
-- [sink]("GI.GObject.Objects.ParamSpec#g:method:sink"), [stealQdata]("GI.GObject.Objects.ParamSpec#g:method:stealQdata").
-- 
-- ==== Getters
-- [getBlurb]("GI.GObject.Objects.ParamSpec#g:method:getBlurb"), [getDefaultValue]("GI.GObject.Objects.ParamSpec#g:method:getDefaultValue"), [getName]("GI.GObject.Objects.ParamSpec#g:method:getName"), [getNameQuark]("GI.GObject.Objects.ParamSpec#g:method:getNameQuark"), [getNick]("GI.GObject.Objects.ParamSpec#g:method:getNick"), [getQdata]("GI.GObject.Objects.ParamSpec#g:method:getQdata"), [getRedirectTarget]("GI.GObject.Objects.ParamSpec#g:method:getRedirectTarget").
-- 
-- ==== Setters
-- [setQdata]("GI.GObject.Objects.ParamSpec#g:method:setQdata").

#if defined(ENABLE_OVERLOADING)
    ResolveParamSpecExpressionMethod        ,
#endif



    ) where

import Data.GI.Base.ShortPrelude
import qualified Data.GI.Base.ShortPrelude as SP
import qualified Data.GI.Base.Overloading as O
import qualified Prelude as P

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.GI.Base.BasicTypes as B.Types
import qualified Data.GI.Base.ManagedPtr as B.ManagedPtr
import qualified Data.GI.Base.GArray as B.GArray
import qualified Data.GI.Base.GClosure as B.GClosure
import qualified Data.GI.Base.GError as B.GError
import qualified Data.GI.Base.GHashTable as B.GHT
import qualified Data.GI.Base.GVariant as B.GVariant
import qualified Data.GI.Base.GValue as B.GValue
import qualified Data.GI.Base.GParamSpec as B.GParamSpec
import qualified Data.GI.Base.CallStack as B.CallStack
import qualified Data.GI.Base.Properties as B.Properties
import qualified Data.GI.Base.Signals as B.Signals
import qualified Control.Monad.IO.Class as MIO
import qualified Data.Coerce as Coerce
import qualified Data.Text as T
import qualified Data.Kind as DK
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map
import qualified Foreign.Ptr as FP
import qualified GHC.OverloadedLabels as OL
import qualified GHC.Records as R
import qualified Data.Word as DW
import qualified Data.Int as DI
import qualified System.Posix.Types as SPT
import qualified Foreign.C.Types as FCT

-- Workaround for https://gitlab.haskell.org/ghc/ghc/-/issues/23392
#if MIN_VERSION_base(4,18,0)
import qualified GI.GObject.Objects.ParamSpec as GObject.ParamSpec

#else
import qualified GI.GObject.Objects.ParamSpec as GObject.ParamSpec

#endif

-- | Memory-managed wrapper type.
newtype ParamSpecExpression = ParamSpecExpression (SP.ManagedPtr ParamSpecExpression)
    deriving (Eq)

instance SP.ManagedPtrNewtype ParamSpecExpression where
    toManagedPtr (ParamSpecExpression p) = p

foreign import ccall "gtk_param_expression_get_type"
    c_gtk_param_expression_get_type :: IO B.Types.GType

instance B.Types.TypedObject ParamSpecExpression where
    glibType = c_gtk_param_expression_get_type

-- | Type class for types which can be safely cast to t'ParamSpecExpression', for instance with `toParamSpecExpression`.
class (SP.BoxedPtr o, SP.TypedObject o, O.IsDescendantOf ParamSpecExpression o) => IsParamSpecExpression o
instance (SP.BoxedPtr o, SP.TypedObject o, O.IsDescendantOf ParamSpecExpression o) => IsParamSpecExpression o

instance O.HasParentTypes ParamSpecExpression
type instance O.ParentTypes ParamSpecExpression = '[GObject.ParamSpec.ParamSpec]

-- | Cast to t'ParamSpecExpression', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
toParamSpecExpression :: (MIO.MonadIO m, IsParamSpecExpression o) => o -> m ParamSpecExpression
toParamSpecExpression = MIO.liftIO . B.ManagedPtr.unsafeCastTo ParamSpecExpression

--- XXX Missing getter and/or setter, so no GValue instance could be generated.
#if defined(ENABLE_OVERLOADING)
type family ResolveParamSpecExpressionMethod (t :: Symbol) (o :: DK.Type) :: DK.Type where
    ResolveParamSpecExpressionMethod "sink" o = GObject.ParamSpec.ParamSpecSinkMethodInfo
    ResolveParamSpecExpressionMethod "stealQdata" o = GObject.ParamSpec.ParamSpecStealQdataMethodInfo
    ResolveParamSpecExpressionMethod "getBlurb" o = GObject.ParamSpec.ParamSpecGetBlurbMethodInfo
    ResolveParamSpecExpressionMethod "getDefaultValue" o = GObject.ParamSpec.ParamSpecGetDefaultValueMethodInfo
    ResolveParamSpecExpressionMethod "getName" o = GObject.ParamSpec.ParamSpecGetNameMethodInfo
    ResolveParamSpecExpressionMethod "getNameQuark" o = GObject.ParamSpec.ParamSpecGetNameQuarkMethodInfo
    ResolveParamSpecExpressionMethod "getNick" o = GObject.ParamSpec.ParamSpecGetNickMethodInfo
    ResolveParamSpecExpressionMethod "getQdata" o = GObject.ParamSpec.ParamSpecGetQdataMethodInfo
    ResolveParamSpecExpressionMethod "getRedirectTarget" o = GObject.ParamSpec.ParamSpecGetRedirectTargetMethodInfo
    ResolveParamSpecExpressionMethod "setQdata" o = GObject.ParamSpec.ParamSpecSetQdataMethodInfo
    ResolveParamSpecExpressionMethod l o = O.MethodResolutionFailed l o

instance (info ~ ResolveParamSpecExpressionMethod t ParamSpecExpression, O.OverloadedMethod info ParamSpecExpression p) => OL.IsLabel t (ParamSpecExpression -> p) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.overloadedMethod @info
#else
    fromLabel _ = O.overloadedMethod @info
#endif

#if MIN_VERSION_base(4,13,0)
instance (info ~ ResolveParamSpecExpressionMethod t ParamSpecExpression, O.OverloadedMethod info ParamSpecExpression p, R.HasField t ParamSpecExpression p) => R.HasField t ParamSpecExpression p where
    getField = O.overloadedMethod @info

#endif

instance (info ~ ResolveParamSpecExpressionMethod t ParamSpecExpression, O.OverloadedMethodInfo info ParamSpecExpression) => OL.IsLabel t (O.MethodProxy info ParamSpecExpression) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.MethodProxy
#else
    fromLabel _ = O.MethodProxy
#endif

#endif

-- XXX Wrapping a foreign struct/union with no known destructor or size, leak?
instance BoxedPtr ParamSpecExpression where
    boxedPtrCopy = return
    boxedPtrFree = \_x -> return ()
